@@ -574,3 +574,43 @@ class Configuration(optparse.OptionParser):
                 continue
         else:
             raise ConfigurationProviderException("Could not load %s" % filename)
+
+class UserConfiguration(Configuration):
+    """`Configuration` class driven by a config file in user-space"""
+
+    # configuration items to interpolate as paths
+    # TODO: moar bettur!
+    paths = []
+
+    def __init__(self, config=None, load='--config'):
+
+        # default configuration file
+        self.config_name = config or '.' + os.path.splitext(sys.argv[0])[0]
+        self.default_config_file = os.path.join('~', self.config_name)
+        self.default_config_file_path = os.path.expanduser(self.default_config_file)
+        if os.path.exists(self.default_config_file_path)
+            self.load_help += ' [DEFAULT: %s]' % default_config_file
+
+        Configuration.__init__(self, usage=self.usage, load=load)
+
+    def validate(self):
+        Configuration.validate(self)
+        for path in self.paths:
+            self.config[path] = os.path.expanduser(self.config[path])
+
+    def configuration_files(self, options, args):
+        configuration_files = Configuration.configuration_files(self, options, args)
+        if not configuration_files:
+            # load user config only if no config provided
+            if os.path.exists(self.default_config_file_path):
+                configuration_files = [default_config]
+        return configuration_files
+
+    def load_configuration_file(self, filename):
+        config = Configuration.load_configuration_file(self, filename)
+
+        # ignore options that we don't care about
+        config = dict([(key, value) for key, value in config.items()
+                       if key in self.option_dict])
+
+        return config
